@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
+import logging
 
 from flask import g, jsonify, request
 
@@ -10,8 +11,11 @@ from blueflask.lib.infos import created, no_content
 
 from ...objects import User, SystemAccount
 from ...consts import SERVICE_CODE, LOGS
+from ...core import ldap_conn
 from . import api
 
+import ldap
+
 
 @api.route("/users", methods=["GET"])
 def users():
@@ -394,7 +398,27 @@ def user(username):
             if key not in ["userPassword", "cn", "handler"]
         }
         if hasattr(user, "manager"):
-            infos["manager"] = {"name": user.manager.name, "uid": user.manager.uid}
+            # I hardcoded it because of recursive calls inside this code version Object
+            name = user.manager.split(',')[0][3:]
+            query = (
+                "(&" "(objectClass={object_class})" "({identifier}={value})" ")"
+            ).format(
+                object_class="inetOrgPerson",
+                identifier="cn",
+                value=name
+            )
+            result = ldap_conn(
+                "search_s",
+                "ou=people,dc=blueline,dc=mg",
+                ldap.SCOPE_SUBTREE,
+                filterstr=query,
+                attrlist=["cn", "uid"],
+            )
+            all_info = {key: value[0].decode("utf-8") for key, value in result[0][1].items()}
+            infos["manager"] = {
+                "name": name,
+                "uid": all_info['uid']
+            }
         try:
             infos["department"] = user.department.name
         except IndexError:
