@@ -109,6 +109,11 @@ class LdapHandler:
 
     def parse_search(self, search_result):
         dn, user_info = search_result
+
+        # [!] this will raise UnicodeDecodeError if removed
+        if user_info.get('jpegPhoto'):
+            del user_info['jpegPhoto']
+
         user_info_u = {
             key: value[0].decode("utf-8")
             for key, value in user_info.items()
@@ -190,11 +195,16 @@ class LdapHandler:
         """
         if object_class == "User":
             command = [(ldap.MOD_ADD, "roleOccupant", object_tree.encode('utf-8'))]
-            core.ldap_conn("modify_s", destination_tree, command)
-            consts.LOGS.logger.info(
-                "User {} added to {} list\n"
-                .format(object_tree, destination_tree)
-            )
+            try:
+                core.ldap_conn("modify_s", destination_tree, command)
+                consts.LOGS.logger.info(
+                    "User {} added to {} list\n"
+                    .format(object_tree, destination_tree)
+                )
+            except ldap.TYPE_OR_VALUE_EXISTS:
+                consts.LOGS.logger.info(
+                    "> User already in the position tree\n"
+                )
         else:
             raise NotImplementedError
 
@@ -242,11 +252,13 @@ class LdapHandler:
 
     def _get_next_userid(self):
         all_users = self.search("User")
-        uidNumber_list = []
-        for employee in all_users:
-            dn, user_info = self.parse_search(employee)
-            uidNumber_list.append(int(user_info.get('uidNumber', 0)))
-        return str(max(uidNumber_list) + 1)
+        uid_l = [
+            int(employee[1]['uidNumber'][0].decode('utf-8'))
+            for employee in all_users
+            if employee[1].get('uidNumber')
+        ]
+        next_uid = max(uid_l) + 1
+        return str(next_uid)
 
 
 class EmailHandler(object):
